function [loops,Peak] = DisplayLoopsens(G,C,w,option)
% [loops,Peak] = DisplayLoopsens(G,C,option)
%
%               performs the LOOPSENS command and displays the closed loop 
%               transfer functions
%   loops : structure generated from LOOPSENS
%   Peaks : structure containing the Hinf-norms of the closed loop transfer
%           functions
%        ---
%       option = 's' for singular value plot of the gang-of-six
%
% Robustness Interpretation from Zhou, Doyle, Glover 95
% T  : output (sensor) errors, neglected HF dynamics, changing # of rhp zeros
% Ti : input (actuators) errors, neglected HF dynamics, changing # of rhp zeros
% S  : LF parameter errors, changing # of rhp poles
% Si : LF parameter errors, changing # of rhp poles
% KS : additive plant errors, neglected HF dynamics, uncertain rhp zeros
% SG : LF parameter errors, neglected HF dynamics, uncertain rhp poles & zeros
%
% Signal Interpretation
% T  : noise, reference signal
% S  : output disturbance
% KS : control effort
% SG : input disturbance




if nargin==3
    option = 's';
end
[ny, nu] = size(G);
loops = loopsens(G,C);

[Peak.So, Peak.S] = deal(norm(loops.So,'inf'));
[Peak.PSi, Peak.SG] = deal(norm(loops.PSi,'inf'));
[Peak.CSo, Peak.KS] = deal(norm(loops.CSo,'inf'));
[Peak.Ti, Peak.Ti] = deal(norm(loops.Ti,'inf'));
[Peak.To, Peak.T] = deal(norm(loops.To,'inf'));
[Peak.Si, Peak.Si] = deal(norm(loops.Si,'inf'));

loops.So.InputName = G.OutputName; loops.So.OutputName = G.OutputName;
loops.Si.InputName = G.InputName; loops.Si.OutputName = G.InputName;
loops.To.InputName = G.OutputName; loops.To.OutputName = G.OutputName;
loops.Ti.InputName = G.InputName; loops.Ti.OutputName = G.InputName;
loops.PSi.InputName = G.InputName; loops.PSi.OutputName = G.OutputName;
loops.CSo.InputName = G.OutputName; loops.CSo.OutputName = G.InputName;

        b = bodeoptions;
        b.MagUnits = 'abs';
        

switch lower(option(1))
    case 's'
    figure
    % Gang-of-Six Singular Value Plot
    YL = -40;
    subplot(3,2,1)
        sigma(loops.So,w);grid;ylim([YL(1),db(2*Peak.So)]);
        title('So') % title('S')
    subplot(3,2,2)
        sigma(loops.PSi,w);grid;ylim([YL(1),db(2*Peak.PSi)]);
        title('PSi') % title('SG')
    subplot(3,2,3)
        sigma(loops.CSo,w);grid;ylim([YL(1),db(2*Peak.CSo)]);
        title('CSo')
    subplot(3,2,4)
        sigma(loops.Ti,w);grid;ylim([YL(1),db(2*Peak.Ti)]);
        title('Ti')
    subplot(3,2,5)
        sigma(loops.To,w);grid;ylim([YL(1),db(2*Peak.To)]);
        title('To')
    subplot(3,2,6)
        sigma(loops.Si,w);grid;ylim([YL(1),db(2*Peak.Si)]);
        title('Si')
    if exist('garyfyFigure','file');garyfyFigure; end
        
    case 'i'
    % Multiplicative Uncertainty Input
    for ii=1:nu
    figure
        bodemag(loops.Ti(ii,ii)^-1,b,w);grid;ylim([0,10]);
        ylabel(['Input ' int2str(ii) ' ("' G.InputName{ii} '")'])
        title('Allowed multiplicative uncertainty')
        if exist('garyfyFigure','file');garyfyFigure; end
    end
    
    case 'o'
    % Multiplicative Uncertainty Output
    for ii=1:ny
    figure
        bodemag(loops.To(ii,ii)^-1,b,w);grid;ylim([0,10]);
        ylabel(['Output ' int2str(ii) ' ("' G.OutputName{ii} '")'])
        title('Allowed multiplicative uncertainty')
        if exist('garyfyFigure','file');garyfyFigure; end
    end
    
    case 'a'
    figure        
    % Additive Uncertainty
    [SV, W] = sigma(loops.CSo,w);
        semilogx(W,1./SV);grid;ylim([0,10]);xlim([w{1},w{2}]);
        ylabel(['Singular Values (abs)'])
        title('Allowed additive uncertainty')
        if exist('garyfyFigure','file');garyfyFigure; end
    
end



